@@ -10,12 +10,9 @@ for (config in configs) {
 
   set_default_config(config, permanent = FALSE)
 
-  skip_on_appveyor()
-  skip_on_travis_mac()
+  skip_on_github_actions()
   skip_on_cran()
 
-  if (config$backend == "singularity") skip_on_travis()
-
   test_that(paste0("babelwhale can copy and read a file from ", config$backend), {
     dest <- tempfile()
     copy_file("alpine", "/etc/inittab", dest)
